# notify-idle

## Usage:
```
# 1 recipient
GMX_USER=sender@gmx.com GMX_PASSWORD=password notify-idle recipient@gmail.com MACHINEALIAS

# 2 recipient
GMX_USER=sender@gmx.com GMX_PASSWORD=password notify-idle recipient@gmail.com,recipient2@gmail.com MACHINEALIAS
```
